# FeedbackId

Feedback ID to filter on

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from arthur_observability_sdk._generated.models.feedback_id import FeedbackId

# TODO update the JSON string below
json = "{}"
# create an instance of FeedbackId from a JSON string
feedback_id_instance = FeedbackId.from_json(json)
# print the JSON string representation of the object
print(FeedbackId.to_json())

# convert the object into a dict
feedback_id_dict = feedback_id_instance.to_dict()
# create an instance of FeedbackId from a dict
feedback_id_from_dict = FeedbackId.from_dict(feedback_id_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


